==> haskell-authenticate-1.3.4-323-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: authenticate
version: 1.3.4
id: authenticate-1.3.4-2gLe36519GF1qdj18PD07k
key: authenticate-1.3.4-2gLe36519GF1qdj18PD07k
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman, Hiromi Ishii, Arash Rouhani
stability: Stable
homepage: http://github.com/yesodweb/authenticate
synopsis: Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.
category: Web
abi: 36cf9847464847e3d3f8619e77d4b8c0
exposed: True
exposed-modules:
    Web.Authenticate.BrowserId Web.Authenticate.OpenId
    Web.Authenticate.OpenId.Providers Web.Authenticate.Rpxnow
hidden-modules: Web.Authenticate.Internal OpenId2.Discovery
                OpenId2.Normalization OpenId2.Types OpenId2.XRDS
import-dirs: /usr/lib/ghc-8.6.5/site-local/authenticate-1.3.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/authenticate-1.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/authenticate-1.3.4
hs-libraries: HSauthenticate-1.3.4-2gLe36519GF1qdj18PD07k
depends:
    aeson-1.4.4.0-KwovUsQGNt8PPlzoq6sTW
    attoparsec-0.13.2.2-JtccVfLzqCgD0Y1SyaKt8t base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    conduit-1.3.1.1-3gq47figCcD3FXjYab6brY containers-0.6.0.1
    http-conduit-2.3.7.1-7C6Yl9aU2q0G8aSce4JTCz
    http-types-0.12.3-4mvqCFA58Pd9Ot84cA11d5
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    resourcet-1.2.2-8hEDHRutAsl8XBsaHNUdIq
    tagstream-conduit-0.5.5.3-BvD9GkCo9CtIDOuBXxyqfM text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
    xml-conduit-1.8.0.1-4bEtXOFZ4ioD9TixoCXC7X
haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
haddock-html: /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-authenticate-1.3.4-324-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: authenticate
version: 1.3.4
id: authenticate-1.3.4-AuRHrLbrTYvA6LXIOtDh6A
key: authenticate-1.3.4-AuRHrLbrTYvA6LXIOtDh6A
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman, Hiromi Ishii, Arash Rouhani
stability: Stable
homepage: http://github.com/yesodweb/authenticate
synopsis: Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.
category: Web
abi: 98e5f1a0e26e4722b2e2bd6e24d72eec
exposed: True
exposed-modules:
    Web.Authenticate.BrowserId Web.Authenticate.OpenId
    Web.Authenticate.OpenId.Providers Web.Authenticate.Rpxnow
hidden-modules: Web.Authenticate.Internal OpenId2.Discovery
                OpenId2.Normalization OpenId2.Types OpenId2.XRDS
import-dirs: /usr/lib/ghc-8.6.5/site-local/authenticate-1.3.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/authenticate-1.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/authenticate-1.3.4
hs-libraries: HSauthenticate-1.3.4-AuRHrLbrTYvA6LXIOtDh6A
depends:
    aeson-1.4.4.0-KwovUsQGNt8PPlzoq6sTW
    attoparsec-0.13.2.2-JtccVfLzqCgD0Y1SyaKt8t base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    conduit-1.3.1.1-3gq47figCcD3FXjYab6brY containers-0.6.0.1
    http-conduit-2.3.7.1-GKSFR4Gz0yQHwJXp1xmwy1
    http-types-0.12.3-4mvqCFA58Pd9Ot84cA11d5
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    resourcet-1.2.2-8hEDHRutAsl8XBsaHNUdIq
    tagstream-conduit-0.5.5.3-BvD9GkCo9CtIDOuBXxyqfM text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
    xml-conduit-1.8.0.1-4bEtXOFZ4ioD9TixoCXC7X
haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
haddock-html: /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
